# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/volunteer/volunteer/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/volunteer/volunteer/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Volunteer\\Volunteer\\": "packages/volunteer/volunteer/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Volunteer\Volunteer\Providers\VolunteerServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Volunteer'  => Volunteer\Volunteer\Facades\Volunteer::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Volunteer\\VolunteerTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Volunteer\Volunteer\Providers\VolunteerServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Volunteer\Volunteer\Providers\VolunteerServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Volunteer\Volunteer\Providers\VolunteerServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/volunteer/{modulename}

**User**

    http://path-to-route-folder/user/volunteer/{modulename}

**Public**

    http://path-to-route-folder/volunteers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/volunteer/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/volunteer/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/volunteer/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/volunteer/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/volunteer/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/volunteer/{modulename}/{slug}
    METHOD: GET